summaryrefslogtreecommitdiffstats
path: root/assets
diff options
context:
space:
mode:
authorAndrew Sapperstein <asapperstein@google.com>2013-07-29 11:16:07 -0700
committerAndrew Sapperstein <asapperstein@google.com>2013-07-29 11:16:07 -0700
commit1f082231c4a51eb3be37df6d2a0024634dfe4a9b (patch)
treefdea27c92d6ee1a50857da607ce27f4d8674a83f /assets
parent8afccad8b03701577bb4b734a0f4fe76f6cab487 (diff)
downloadandroid_packages_apps_UnifiedEmail-1f082231c4a51eb3be37df6d2a0024634dfe4a9b.tar.gz
android_packages_apps_UnifiedEmail-1f082231c4a51eb3be37df6d2a0024634dfe4a9b.tar.bz2
android_packages_apps_UnifiedEmail-1f082231c4a51eb3be37df6d2a0024634dfe4a9b.zip
Properly Update conv when new message added.
Previously we weren't adding the right items. Need to not add a top border but add a border at the end. Additionally needed to change the javascript to also add the spacer for the bottom border. Change-Id: Ief82dca25c0c11b258cfe9a3d783d6c4f2e62974
Diffstat (limited to 'assets')
-rw-r--r--assets/script.js6
1 files changed, 4 insertions, 2 deletions
diff --git a/assets/script.js b/assets/script.js
index d822535f8..be22529dd 100644
--- a/assets/script.js
+++ b/assets/script.js
@@ -704,8 +704,10 @@ function replaceMessageBodies(messageIds) {
function appendMessageHtml() {
var msg = document.createElement("div");
msg.innerHTML = window.mail.getTempMessageBodies();
- msg = msg.children[0]; // toss the outer div, it was just to render innerHTML into
- document.body.appendChild(msg);
+ var body = msg.children[0]; // toss the outer div, it was just to render innerHTML into
+ var border = msg.children[1]; // get the border spacer as well
+ document.body.appendChild(body);
+ document.body.appendChild(border);
processQuotedText(msg, true /* showElided */);
hideUnsafeImages(msg.getElementsByClassName("mail-message-content"));
measurePositions();